@@ -136,7 +136,7 @@ def main():
 
     # if everything is ok, set exit
     if not critical_messages and not warning_messages:
-        print("OK - All SRs within usage range")
+        print("OK - All SRs within thresholds")
         sys.exit(exit_code)
     
     # Output results
